@@ -11,7 +11,6 @@ import CompNeuroPy.Experiment"""
 
 from CompNeuroPy.analysis_functions import *
 from CompNeuroPy.extra_functions import *
-from CompNeuroPy.generate_model import *
 from CompNeuroPy.model_functions import *
 from CompNeuroPy.neuron_models import *
 from CompNeuroPy.simulation_functions import *
@@ -19,3 +18,4 @@ from CompNeuroPy.system_functions import *
 from CompNeuroPy.opt_neuron import opt_neuron
 from CompNeuroPy.Monitors import Monitors
 from CompNeuroPy.Experiment import Experiment
+from CompNeuroPy.generate_model import generate_model
